@@ -21,23 +21,7 @@
 #include "config.h"
 #include "devhelp.h"
 
-#include "ige-conf.h"
-#include "dh-util.h"
-
-static void
-load_config_defaults (void)
-{
-        IgeConf    *conf;
-        gchar      *path;
-
-        conf = ige_conf_get ();
-        path = dh_util_build_data_filename ("devhelp", "devhelp.defaults", NULL);
-        ige_conf_add_defaults (conf, path);
-        g_free (path);
-}
-
 void
 dh_init (void)
 {
-        load_config_defaults ();
 }
