@@ -23,6 +23,7 @@
 #define __DH_UTIL_H__
 
 #include <gtk/gtk.h>
+#include <gio/gio.h>
 #ifdef HAVE_WEBKIT2
 #include <webkit2/webkit2.h>
 #else
@@ -43,31 +44,6 @@ void         dh_util_builder_connect              (GtkBuilder  *gui,
                                                    ...);
 gchar *      dh_util_build_data_filename          (const gchar *first_part,
                                                    ...);
-void         dh_util_state_manage_window          (GtkWindow   *window,
-                                                   const gchar *name);
-void         dh_util_state_manage_paned           (GtkPaned    *paned,
-                                                   const gchar *name);
-void         dh_util_state_manage_notebook        (GtkNotebook *notebook,
-                                                   const gchar *name,
-                                                   const gchar *default_tab);
-void         dh_util_state_set_notebook_page_name (GtkWidget   *page,
-                                                   const gchar *page_name);
-const gchar *dh_util_state_get_notebook_page_name (GtkWidget   *page);
-
-GSList *     dh_util_state_load_books_disabled    (void);
-void         dh_util_state_store_books_disabled   (GSList *books_disabled);
-
-gboolean     dh_util_state_load_group_books_by_language  (void);
-void         dh_util_state_store_group_books_by_language (gboolean group_books_by_language);
-
-void         dh_util_font_get_variable            (gchar        **name,
-                                                   gdouble       *size,
-                                                   gboolean       use_system_font);
-void         dh_util_font_get_fixed               (gchar        **name,
-                                                   gdouble       *size,
-                                                   gboolean       use_system_font);
-void         dh_util_font_add_web_view            (WebKitWebView *view);
-
 gint         dh_util_cmp_book                     (DhLink *a,
                                                    DhLink *b);
 
@@ -75,6 +51,18 @@ void         dh_util_ascii_strtitle               (gchar *str);
 gchar       *dh_util_create_data_uri_for_filename (const gchar *filename,
                                                    const gchar *mime_type);
 
+void         dh_util_view_set_font                (WebKitWebView *view,
+                                                   const gchar *font_name_fixed,
+                                                   const gchar *font_name_variable);
+
+void         dh_util_window_settings_save         (GtkWindow *window,
+                                                   GSettings *settings,
+                                                   gboolean has_maximize);
+
+void         dh_util_window_settings_restore      (GtkWindow *window,
+                                                   GSettings *settings,
+                                                   gboolean has_maximize);
+
 G_END_DECLS
 
 #endif /* __DH_UTIL_H__ */
